@@ -887,10 +887,9 @@ class TrialMetadata(CommonColumns):
             select
                 trial_id,
                 'file_size_bytes' as key,
-                sum(file_size_bytes) as value
+                file_size_bytes as value
             from
                 downloadable_files
-            group by trial_id
         """
 
         # Compute the number of samples associated with each assay type for
@@ -900,14 +899,17 @@ class TrialMetadata(CommonColumns):
         generic_assay_subquery = """
             select
                 trial_id,
-                key as key,
-                sum(jsonb_array_length(batches->'records')) as value
+                case
+                    when key = 'cytof_10021' then 'cytof'
+                    when key = 'hande' then 'h&e'
+                    else key
+                end as key,
+                jsonb_array_length(batches->'records') as value
             from
                 trial_metadata,
                 jsonb_each(metadata_json->'assays') assays,
                 jsonb_array_elements(value) batches
-            where key not in ('olink', 'nanostring')
-            group by trial_id, key
+            where key not in ('olink', 'nanostring', 'elisa', 'cytof_e4412')
         """
 
         # Compute the number of samples associated with nanostring uploads.
@@ -918,12 +920,11 @@ class TrialMetadata(CommonColumns):
             select
                 trial_id,
                 'nanostring' as key,
-                sum(jsonb_array_length(runs->'samples')) as value
+                jsonb_array_length(runs->'samples') as value
             from
                 trial_metadata,
                 jsonb_array_elements(metadata_json#>'{assays,nanostring}') batches,
                 jsonb_array_elements(batches->'runs') runs
-            group by trial_id
         """
 
         # Compute the number of samples associated with olink uploads.
@@ -937,12 +938,40 @@ class TrialMetadata(CommonColumns):
             select
                 trial_id,
                 'olink' as key,
-                sum((records#>'{files,assay_npx,number_of_samples}')::text::integer) as value
+                (records#>'{files,assay_npx,number_of_samples}')::text::integer as value
             from
                 trial_metadata,
                 jsonb_array_elements(metadata_json#>'{assays,olink,batches}') batches,
                 jsonb_array_elements(batches->'records') records
-            group by trial_id
+        """
+
+        # Compute the number of samples associated with elisa uploads.
+        # Unlike other assays, elisa metadata is an array of entries, each containing a single data file.
+        # The number of samples corresponding to a given entry is stored like:
+        # entry["assay_xlsx"]["number_of_samples"].
+        elisa_subquery = """
+            select
+                trial_id,
+                'elisa' as key,
+                (entry#>'{assay_xlsx,number_of_samples}')::text::integer as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{assays,elisa}') entry
+        """
+
+        # Compute the number of samples associated with cytof_4412 uploads.
+        # cytof_e4412 metadata has a slightly different structure than typical
+        # assays, where each batch has an array of participants, and each participant has
+        # an array of sample-level entries.
+        cytof_e4412_subquery = """
+            select
+                trial_id,
+                'cytof' as key,
+                jsonb_array_length(participant->'samples') as value
+            from
+                trial_metadata,
+                jsonb_array_elements(metadata_json#>'{assays,cytof_e4412}') batches,
+                jsonb_array_elements(batches->'participants') participant
         """
 
         # All the subqueries produce the same set of columns, so `UNION`
@@ -952,14 +981,25 @@ class TrialMetadata(CommonColumns):
             select
                 jsonb_object_agg(key, value) || jsonb_object_agg('trial_id', trial_id)
             from (
-                {files_subquery}
-                union
-                {generic_assay_subquery}
-                union
-                {nanostring_subquery}
-                union
-                {olink_subquery}
-            ) q
+                select
+                    trial_id,
+                    key,
+                    sum(value) as value
+                from (
+                    {files_subquery}
+                    union
+                    {generic_assay_subquery}
+                    union
+                    {nanostring_subquery}
+                    union
+                    {olink_subquery}
+                    union
+                    {elisa_subquery}
+                    union all
+                    {cytof_e4412_subquery}
+                ) q1
+                group by trial_id, key
+            ) q2
             group by trial_id;
         """
 
